@@ -16,8 +16,7 @@ and
 .B bar
 commands.
 This manual page was written for the Debian GNU/Linux distribution
-(but may be used by others), because the original program does not
-have a manual page.
+because the original program does not have a manual page.
 Instead, it has documentation in the GNU Info format; see below.
 .PP
 .B #PACKAGE#
@@ -39,4 +38,4 @@ The programs are documented fully by
 available via the Info system.
 .SH AUTHOR
 This manual page was written by #USERNAME# <#EMAIL#>,
-for the Debian GNU/Linux system.
+for the Debian GNU/Linux system (but may be used by others).
